Extractor
--------------------

The extractors are used to extract the features from the document. :code:`extract_metrics` is meant to be called on raw texts, whereas :code:`extract_df` and :code:`extract_dict` work on spaCy documents (:code:`Doc`).


API
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autofunction:: textdescriptives.extractors.extract_metrics
.. autofunction:: textdescriptives.extractors.extract_df
.. autofunction:: textdescriptives.extractors.extract_dict